@@ -7,7 +7,7 @@ use Socket qw(:DEFAULT inet_ntop);
 use Errno;
 use base 'Exporter';
 
-our $VERSION = '0.14';
+our $VERSION = '0.15';
 our @EXPORT_OK = ('connect', 'wrap_connection');
 
 # cache
@@ -24,7 +24,7 @@ sub _io_socket_connect_ref {
 # fake handle to put under event loop while making socks handshake
 sub _get_blocking_handles {
 	pipe(my $blocking_reader, my $blocking_writer)
-		or die 'socketpair(): ', $!;
+		or die 'pipe(): ', $!;
 	
 	$blocking_writer->blocking(0);
 	$blocking_reader->blocking(0);
@@ -246,7 +246,7 @@ sub _connect {
 		$socket->blocking(0);
 	}
 	
-	return unless $ok;
+	return unless $ok || ($io_handler && $IO::Socket::Socks::SOCKS_ERROR == &IO::Socket::Socks::SOCKS_WANT_WRITE);
 	bless $socket, $ref if $ref && !$io_handler; # XXX: should we unbless for GLOB?
 	
 	if ($io_handler) {
